/*
 Foundation.h - basic component class
 base class for other classes: defines protocol for derived classes

 Douglas A. Young, 'Object-oriented Programming with C++ and OSF/Motif'
 2nd ed., Prentice-Hall
*/

#ifndef FOUNDATION_H
#define FOUNDATION_H

#include <Xm/Xm.h>


class Foundation
{
	public:
		virtual ~Foundation();
		virtual void manage();		// (un)manage widget tree
		virtual void unmanage();
		const Widget baseWidget() { return ( _w ); }

	protected:
		char *_name;
		Widget _w;
		Foundation ( const char * ); // constructor protected to avoid instantiation 
};


/*
 Notes:

 _w data member is widget which is root of any component's widget tree.

 baseWidget() provides public access to it.

 _name is normally the name of the base widget.

 Derived classes can call the Foundation constructor from their own.
 Manage and unmanage are public: other classes or the application can
 display/hide a component class widget collection by operating on the
 base widget. Virtual, so other classes can change this behaviour if
 additional actions are needed when the component is (un)managed.
*/

#endif
